@@ -41,7 +41,7 @@ class PartnerPoint(CreatePointMixin, ContractPoint):
     _create_contract = PartnerCreateContract
 
 
-class PartnerObjectPoint(CreatePointMixin, ContractObjectPoint):
+class PartnerObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractObjectPoint):
     _point_id = PartnerID()
     _read_contract = PartnerReadContract
     _update_contract = PartnerUpdateContract
